package com.iformall.mapper;

import java.util.*;
import com.iformall.common.CommonMapper;
import com.iformall.domain.po.WxMerchant;
import com.iformall.domain.po.WxTopic;
import com.iformall.domain.vo.WxCouponCVo;
import com.iformall.domain.vo.WxCouponChannelVo;
import com.iformall.domain.po.WxCouponChannel;
import org.apache.ibatis.annotations.Param;

public interface WxCouponChannelMapper extends CommonMapper<WxCouponChannel, String> {

	List<WxCouponChannel> findList(WxCouponChannel wxCouponChannel);

	int countCoupon(WxCouponChannel wxCouponChannel);

	int countCouponChannel(WxCouponChannel wxCouponChannel);

	List<WxCouponChannelVo> findVoList(WxCouponChannel wxCouponChannel);

	List<WxCouponChannelVo> findVoListByMerchant(WxCouponChannel wxCouponChannel);

	WxCouponCVo findVoDetail(@Param("id")Long id);

	WxCouponCVo findVoStatusDetail(@Param("id")Long id);

	void updateStatusByCouponId(WxCouponChannel wxCouponChannel);

    int updateEndTimeByCouponId(WxCouponChannel  wxCouponChannel);

	void offExpiriedCouponChannelByEndTime();

	void offExpiriedCouponChannelByValidDate();

	void offExpiriedCouponChannelByCouponStatus();

	void offExpiriedCouponChannel2ByEndTime();

	void delByTopic(WxTopic wxTopic);

	List<WxCouponChannel> findQrcodeEmptyList();
}
